@@ -16,7 +16,16 @@
 #   PREFIX      = "drive",
 # )
 
-glue_data_lines <- function(.data, lines, ..., .envir = parent.frame()) {
+# 2023-03 developments related to the 'app' -> 'client' transition:
+# - `PREFIX_auth_configure_description()` crosslinks to
+#   `PREFIX_oauth_client()` now, not `PREFIX_oauth_app()`
+# - `PREFIX_auth_configure_params()` gains `client` argument
+# - `PREFIX_auth_configure_params()` deprecates the `app` argument and uses a
+#   lifecycle badge
+# - `PREFIX_auth_configure_params() crosslinks to
+#   `gargle::gargle_oauth_client_from_json()` which requires gargle (>= 1.3.0)
+
+glue_data_lines <- function(.data, lines, ..., .envir = caller_env()) {
   # work around name collision of `.x` of map_chr() vs. of glue_data()
   # and confusion re: `...` of glue_data_lines() vs. `...` of map_chr()
   # plus: I've only got compat-purrr here, so I have to write a function
@@ -42,14 +51,7 @@ PREFIX_auth_description <- function(.data = list(
     "credentials are cached in a folder below your home directory, from where",
     "they can be automatically refreshed, as necessary. Storage at the user",
     "level means the same token can be used across multiple projects and",
-    "tokens are less likely to be synced to the cloud by accident.",
-    "",
-    "If you are interacting with R within a browser (applies to RStudio Server,",
-    "Posit Workbench, and Posit Cloud), you need a variant of this flow,",
-    "known as out-of-band auth (\"oob\"). If this does not happen",
-    "automatically, you can request it yourself with `use_oob = TRUE` or,",
-    "more persistently, by setting an option via",
-    "`options(gargle_oob_default = TRUE)`."
+    "tokens are less likely to be synced to the cloud by accident."
   ), .data = .data)
 }
 
@@ -62,26 +64,40 @@ PREFIX_auth_details <- function(.data = list(
     "Most users, most of the time, do not need to call `{PREFIX}_auth()`",
     "explicitly -- it is triggered by the first action that requires",
     "authorization. Even when called, the default arguments often suffice.",
-    "However, when necessary, this function allows the user to explicitly:",
-    "  * Declare which Google identity to use, via an email address. If there",
-    "    are multiple cached tokens, this can clarify which one to use. It can",
-    "    also force {PACKAGE} to switch from one identity to another. If",
-    "    there's no cached token for the email, this triggers a return to the",
-    "    browser to choose the identity and give consent. You can specify just",
-    "    the domain by using a glob pattern. This means that a script",
-    "    containing `email = \"*@example.com\"` can be run without further",
-    "    tweaks on the machine of either `alice@example.com` or",
-    "    `bob@example.com`.",
-    "  * Use a service account token or workload identity federation.",
-    "  * Bring their own [Token2.0][httr::Token-class].",
-    "  * Specify non-default behavior re: token caching and out-of-bound",
-    "    authentication.",
-    "  * Customize scopes.",
+    "",
+    "However, when necessary, `{PREFIX}_auth()` allows the user to explicitly:",
+    "  * Declare which Google identity to use, via an `email` specification.",
+    "  * Use a service account token or workload identity federation via",
+    "    `path`.",
+    "  * Bring your own `token`.",
+    "  * Customize `scopes`.",
+    "  * Use a non-default `cache` folder or turn caching off.",
+    "  * Explicitly request out-of-band (OOB) auth via `use_oob`.",
+    "",
+    "If you are interacting with R within a browser (applies to RStudio",
+    "Server, Posit Workbench, Posit Cloud, and Google Colaboratory), you need",
+    "OOB auth or the pseudo-OOB variant. If this does not happen",
+    "automatically, you can request it explicitly with `use_oob = TRUE` or,",
+    "more persistently, by setting an option via",
+    "`options(gargle_oob_default = TRUE)`.",
+    "",
+    "The choice between conventional OOB or pseudo-OOB auth is determined",
+    "by the type of OAuth client. If the client is of the \"installed\" type,",
+    "`use_oob = TRUE` results in conventional OOB auth. If the client is of",
+    "the \"web\" type, `use_oob = TRUE` results in pseudo-OOB auth. Packages",
+    "that provide a built-in OAuth client can usually detect which type of",
+    "client to use. But if you need to set this explicitly, use the",
+    "`\"gargle_oauth_client_type\"` option:",
+    "```r",
+    "options(gargle_oauth_client_type = \"web\")       # pseudo-OOB",
+    "# or, alternatively",
+    "options(gargle_oauth_client_type = \"installed\") # conventional OOB",
+    "```",
     "",
     "For details on the many ways to find a token, see",
     "[gargle::token_fetch()]. For deeper control over auth, use",
     "[{PREFIX}_auth_configure()] to bring your own OAuth client or API key.",
-    "Read more about gargle options, see [gargle::gargle_options]."
+    "To learn more about gargle options, see [gargle::gargle_options]."
   ), .data = .data)
 }
 
@@ -197,8 +213,8 @@ PREFIX_auth_configure_description <- function(.data = list(
         "    requests are sent with an API key in lieu of a token."
       )
     },
-    "See the vignette",
-    "[How to get your own API credentials](https://gargle.r-lib.org/articles/get-api-credentials.html)",
+    "",
+    'See the `vignette("get-api-credentials", package = "gargle")`',
     "for more.",
     if (.fallbacks) {
       c(
@@ -206,13 +222,14 @@ PREFIX_auth_configure_description <- function(.data = list(
         "are used."
       )
     },
+    "",
     if (.has_api_key) {
       c(
-        "`{PREFIX}_oauth_app()` and `{PREFIX}_api_key()` retrieve the",
+        "`{PREFIX}_oauth_client()` and `{PREFIX}_api_key()` retrieve the",
         "currently configured OAuth client and API key, respectively."
       )
     } else {
-      "`{PREFIX}_oauth_app()` retrieves the currently configured OAuth client."
+      "`{PREFIX}_oauth_client()` retrieves the currently configured OAuth client."
     }
   )
   glue_data_lines(lines, .data = .data)
@@ -220,12 +237,15 @@ PREFIX_auth_configure_description <- function(.data = list(
 
 PREFIX_auth_configure_params <- function(.has_api_key = TRUE) {
   c(
-    "@param app A Google OAuth client, preferably constructed via",
-    "[gargle::gargle_oauth_client_from_json()]",
+    "@param client A Google OAuth client, presumably constructed via",
+    "[gargle::gargle_oauth_client_from_json()]. Note, however, that it is",
+      "preferred to specify the client with JSON, using the `path` argument.",
     "@inheritParams gargle::gargle_oauth_client_from_json",
     if (.has_api_key) {
       "@param api_key API key."
-    }
+    },
+    "@param app `r lifecycle::badge('deprecated')` Replaced by the `client`",
+    "argument."
   )
 }
 
@@ -236,7 +256,7 @@ PREFIX_auth_configure_return <- function(.data = list(
     "@return",
     "  * `{PREFIX}_auth_configure()`: An object of R6 class",
     "    [gargle::AuthState], invisibly.",
-    "  * `{PREFIX}_oauth_app()`: the current user-configured OAuth client.",
+    "  * `{PREFIX}_oauth_client()`: the current user-configured OAuth client.",
     if (.has_api_key) {
       "  * `{PREFIX}_api_key()`: the current user-configured API key."
     }
