@@ -128,27 +128,23 @@ writeLines(names(cred_funs_list()))
 #  )
 
 ## ---- eval = FALSE------------------------------------------------------------
-#  The thingyr package is requesting access to your Google account. Select a
-#  pre-authorised account or enter '0' to obtain a new token. Press Esc/Ctrl + C to
-#  abort.
-#  
-#  1: janedoe_personal@gmail.com
-#  2: janedoe@example.com
-#  3: janedoe_work@gmail.com
-#  
-#  Selection: 3
+#  The thingyr package is requesting access to your Google account.
+#  Enter '1' to start a new auth process or select a pre-authorized account.
+#  1: Send me to the browser for a new auth process.
+#  2: janedoe_personal@gmail.com
+#  3: janedoe@example.com
+#  4: janedoe_work@gmail.com
+#  Selection:
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  thingy_auth(email = "janedoe_work@gmail.com")
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  gargle_oauth_sitrep()
-#  #' gargle OAuth cache path:
-#  #' /Users/janedoe/.R/gargle/gargle-oauth
+#  #> 14 tokens found in this gargle OAuth cache:
+#  #> ~/Library/Caches/gargle
 #  #'
-#  #' 14 tokens found
-#  #'
-#  #' email                         app         scope                          hash...
+#  #' email                         app         scopes                         hash...
 #  #' ----------------------------- ----------- ------------------------------ ----------
 #  #' abcdefghijklm@gmail.com       thingy      ...bigquery, ...cloud-platform 128f9cc...
 #  #' buzzy@example.org             gargle-demo                                15acf95...
@@ -165,3 +161,9 @@ writeLines(names(cred_funs_list()))
 #  #' abcdefghijklm@gmail.com       tidyverse   ...bigquery, ...cloud-platform ece63f4...
 #  #' nopqr@ABCDEFG.com             tidyverse   ...spreadsheets                f178dd8...
 
+## -----------------------------------------------------------------------------
+writeLines(names(cred_funs_list()))
+
+## ----eval = FALSE-------------------------------------------------------------
+#  gargle::cred_funs_add(credentials_gce = NULL)
+
