@@ -7,7 +7,7 @@ f <- function(ssid = deaths_id, i = 0) {
     "sheets.spreadsheets.get",
     params = list(spreadsheetId = ssid, fields = "spreadsheetId")
   )
-  raw_resp <- googlesheets4::request_make(req)
+  raw_resp <- gargle::request_make(req)
   code <- httr::status_code(raw_resp)
   cat(i, "code:", code, "\n")
   if (code >= 200 && code < 300) {
@@ -20,7 +20,7 @@ f <- function(ssid = deaths_id, i = 0) {
 n <- 300
 i <- 0
 resp <- TRUE
-while(isTRUE(resp) && i < n) {
+while (isTRUE(resp) && i < n) {
   i <- i + 1
   resp <- f(i = i)
 }
