@@ -25,8 +25,8 @@ test_that("email can be set in option", {
 })
 
 test_that("Attempt to initiate OAuth2 flow fails if non-interactive", {
-  rlang::local_interactive(FALSE)
-  expect_error(gargle2.0_token(cache = FALSE), "requires an interactive session")
+  local_interactive(FALSE)
+  expect_snapshot(gargle2.0_token(cache = FALSE), error = TRUE)
 })
 
 test_that("`email = NA`, `email = FALSE` means we don't consult the cache", {
@@ -49,20 +49,20 @@ test_that("`email = NA`, `email = FALSE` means we don't consult the cache", {
   expect_gargle2.0_token(fauxen_in, fauxen_out)
 
   # `email = NA` and `email = FALSE` prevent the cache from being consulted
-  expect_error(
+  expect_snapshot(
     gargle2.0_token(email = NA, cache = cache_folder),
-    "OAuth2 flow requires an interactive session"
+    error = TRUE
   )
-  expect_error(
+  expect_snapshot(
     gargle2.0_token(email = FALSE, cache = cache_folder),
-    "OAuth2 flow requires an interactive session"
+    error = TRUE
   )
 })
 
 test_that("Gargle2.0 prints nicely", {
   fauxen <- gargle2.0_token(
     email = "a@example.org",
-    app = httr::oauth_app("APPNAME", key = "KEY", secret = "SECRET"),
+    client = gargle_oauth_client(id = "CLIENT_ID", secret = "SECRET", name = "CLIENT"),
     credentials = list(a = 1),
     cache = FALSE
   )
@@ -123,3 +123,14 @@ test_that("we can identify the redirect URI suitable for pseudo-OOB flow", {
   )
   expect_equal(select_pseudo_oob_value(redirect_uris), redirect_uris[4])
 })
+
+test_that("gargle2.0_token(app) is deprecated but still works", {
+  withr::local_options(lifecycle_verbosity = "warning")
+  client <- gargle_oauth_client(id = "CLIENT_ID", secret = "SECRET", name = "ABC")
+
+  expect_snapshot(
+    t <- gargle2.0_token(email = NA, credentials = list(a = 1), app = client)
+  )
+  expect_equal(t$client$name, "ABC")
+  expect_equal(t$app$appname, "ABC")
+})
