@@ -3,14 +3,10 @@ test_that("credentials_app_default_path(), default, non-Windows", {
     GOOGLE_APPLICATION_CREDENTIALS = NA, CLOUDSDK_CONFIG = NA,
     APPDATA = NA, SystemDrive = NA
   ))
-  with_mock(
-    is_windows = function() FALSE,
-    {
-      expect_equal(
-        credentials_app_default_path(),
-        path_home(".config", "gcloud", "application_default_credentials.json")
-      )
-    }
+  local_mocked_bindings(is_windows = function() FALSE)
+  expect_equal(
+    credentials_app_default_path(),
+    path_home(".config", "gcloud", "application_default_credentials.json")
   )
 })
 
@@ -19,14 +15,10 @@ test_that("credentials_app_default_path(), default, Windows", {
     GOOGLE_APPLICATION_CREDENTIALS = NA, CLOUDSDK_CONFIG = NA,
     APPDATA = NA, SystemDrive = NA
   ))
-  with_mock(
-    is_windows = function() TRUE,
-    {
-      expect_equal(
-        credentials_app_default_path(),
-        path("C:", "gcloud", "application_default_credentials.json")
-      )
-    }
+  local_mocked_bindings(is_windows = function() TRUE)
+  expect_equal(
+    credentials_app_default_path(),
+    path("C:", "gcloud", "application_default_credentials.json")
   )
 })
 
@@ -35,14 +27,10 @@ test_that("credentials_app_default_path(), system drive, Windows", {
     GOOGLE_APPLICATION_CREDENTIALS = NA, CLOUDSDK_CONFIG = NA,
     APPDATA = NA, SystemDrive = "D:"
   ))
-  with_mock(
-    is_windows = function() TRUE,
-    {
-      expect_equal(
-        credentials_app_default_path(),
-        path("D:", "gcloud", "application_default_credentials.json")
-      )
-    }
+  local_mocked_bindings(is_windows = function() TRUE)
+  expect_equal(
+    credentials_app_default_path(),
+    path("D:", "gcloud", "application_default_credentials.json")
   )
 })
 
@@ -51,14 +39,10 @@ test_that("credentials_app_default_path(), APPDATA env var, Windows", {
     GOOGLE_APPLICATION_CREDENTIALS = NA, CLOUDSDK_CONFIG = NA,
     APPDATA = path("D:", "AppData"), SystemDrive = "D:"
   ))
-  with_mock(
-    is_windows = function() TRUE,
-    {
-      expect_equal(
-        credentials_app_default_path(),
-        path("D:", "AppData", "gcloud", "application_default_credentials.json")
-      )
-    }
+  local_mocked_bindings(is_windows = function() TRUE)
+  expect_equal(
+    credentials_app_default_path(),
+    path("D:", "AppData", "gcloud", "application_default_credentials.json")
   )
 })
 
